@@ -367,7 +367,7 @@ DECLARE_UNIQUE_INDEX(pg_shard_node_oid_index, 6666, on pg_shard_node using btree
 #define ShardNodeOidIndexId 6666
 DECLARE_UNIQUE_INDEX(pg_shard_oid_index, 6667, on pg_shard using btree(id oid_ops));
 #define ShardOidIndexId 6667
-DECLARE_INDEX(pg_shard_node_shardid_index, 6668, on pg_shard_node using btree(shard_id oid_ops));
+DECLARE_UNIQUE_INDEX(pg_shard_node_shardid_index, 6668, on pg_shard_node using btree(shard_id oid_ops, id oid_ops));
 #define ShardNodeShardIdIndexId 6668
 DECLARE_UNIQUE_INDEX(pg_shard_node_ip_port_svr_index, 6669, on pg_shard_node using btree(hostaddr text_pattern_ops, port int4_ops, svr_node_id oid_ops));
 #define ShardNodeIpPortSrvIndexId 6669
@@ -381,4 +381,23 @@ DECLARE_UNIQUE_INDEX(pg_cluster_meta_id_index, 6673, on pg_cluster_meta using bt
 #define ClusterMetaIdIndexId 6673
 DECLARE_UNIQUE_INDEX(pg_ddl_log_dbid_index, 6674, on pg_ddl_log_progress using btree(dbid oid_ops));
 #define DDLLogDbidIndexId 6674
+DECLARE_UNIQUE_INDEX(pg_comp_nodes_id_index, 6675, on pg_comp_nodes using btree(id oid_ops));
+#define CompNodesIdIndex 6675
+
+DECLARE_UNIQUE_INDEX(pg_mysql_charset_mapping_pg_charset_enc_idx, 6676, on pg_mysql_charset_mapping using btree(pg_charset_enc int4_ops));
+#define PgMysqlCharsetMappingPgcsencIdx 6676
+
+DECLARE_UNIQUE_INDEX(pg_mysql_collation_mapping_mysql_coll_idx, 6677, on pg_mysql_collation_mapping using btree(mysql_collation_code int4_ops));
+#define PgMysqlCollsMappingMysqlCollIdx 6677
+DECLARE_UNIQUE_INDEX(pg_mysql_collation_mapping_mysql_cs_coll_names_idx, 6678, on pg_mysql_collation_mapping using btree(mysql_csname name_ops, mysql_collname name_ops));
+#define PgMysqlCollsMappingMysqlCsCollNamesIdx 6678
+DECLARE_UNIQUE_INDEX(pg_mysql_collation_mapping_mysql_coll_name_idx, 6679, on pg_mysql_collation_mapping using btree(mysql_collname name_ops));
+#define PgMysqlCollsMappingMysqlCollNameIdx 6679
+
+DECLARE_UNIQUE_INDEX(pg_proc_map_proname_args_nsp_index, 7000, on pg_proc_map using btree(proname name_ops, proargtypes oidvector_ops, pronamespace oid_ops));
+#define ProcedureMapNameArgsNspIndexId 7000
+
+DECLARE_UNIQUE_INDEX(pg_type_map_typname_nsp_index,7001, on pg_type_map using btree(typname name_ops, typnamespace oid_ops));
+#define TypeMapNameNspIndexId	7001
+
 #endif							/* INDEXING_H */
