@@ -31,7 +31,8 @@
 #include "utils/algos.h"
 #include "nodes/tidbitmap.h"
 #include "storage/condition_variable.h"
-#include "sharding/sharding_conn.h"
+//#include "sharding/sharding_conn.h"
+#include "sharding/stmt_hdl.h"
 
 
 struct PlanState;				/* forward references in this file */
@@ -39,20 +40,23 @@ struct ParallelHashJoinState;
 struct ExprState;
 struct ExprContext;
 struct ExprEvalStep;			/* avoid including execExpr.h everywhere */
-struct RemoteJoinState;
 
 struct EnumLabelOid;
 typedef struct TypeInputInfo
 {
+	char typcat;
+	int typmod;
 	Oid typinput;
 	Oid typioparam;
 	bool typisenum;
 	uint16_t nslots;
-	struct EnumLabelOid*AllEnumLabelOidEntries;
+	struct EnumLabelOid *enum_label_enties;
 	MemoryContext mctx;
+	/* Cached function call info for better performance */
+	FmgrInfo flinfo;
+	FunctionCallInfoData fcinfo;
 } TypeInputInfo;
 
-
 /* ----------------
  *		ExprState node
  *
@@ -456,6 +460,9 @@ typedef struct ResultRelInfo
 	/* for removing junk attributes from tuples */
 	JunkFilter *ri_junkFilter;
 
+	/* junk attributes used by ModifyTable to route tuples on partitioned table */
+	JunkFilter *ri_junkTableoid;
+
 	/* list of RETURNING expressions */
 	List	   *ri_returningList;
 
@@ -497,6 +504,9 @@ typedef struct ResultRelInfo
  * Master working state for an Executor invocation
  * ----------------
  */
+#define REPLICA_READ_NONE	0
+#define REPLICA_READ_FALSE	-1
+#define REPLICA_READ_TRUE	1
 typedef struct EState
 {
 	NodeTag		type;
@@ -603,23 +613,9 @@ typedef struct EState
 	int			es_jit_flags;
 	struct JitContext *es_jit;
 	struct JitInstrumentation *es_jit_worker_instr;
-	/*
-	  dzw:
-	  A remote join subtree of a plan tree must be targeted to the same shard.
-	  We want to fold all RJ nodes to the root RJ node in order to send one SQL
-	  stmt to push down the whole RJ subtree.
-	*/
-	struct RemoteJoinState *root_remote_join;
 	
-	/*
-	  dzw: OLD (Order by, Limit and Distinct) state for current executed
-	  plan tree.
-	  root is that of the root OLD node, top is that of the leaf(plan node
-	  tree) OLD node. such state objects form a stack corresponding to
-	  current executed plan tree path from root to leaf.
-	*/
-	struct Remote_OLD_state *root_old_state;
-	struct Remote_OLD_state *top_old_state;
+	/* Strategy of replica read */
+	int es_replica_read;
 } EState;
 
 
@@ -1079,51 +1075,53 @@ typedef struct ProjectSetState
 	MemoryContext argcontext;	/* context for SRF arguments */
 } ProjectSetState;
 
+struct AsyncStmtInfo;
 typedef struct RemoteModifyState
 {
-	AsyncStmtInfo *asi;         /* communication channel with storage node. */
+	struct AsyncStmtInfo *asi;         /* communication channel with storage node. */
 	StringInfoData remote_dml;
+	StmtSafeHandle handle;
 } RemoteModifyState;
 
+struct RemoteUD;
 /* ----------------
  *	 ModifyTableState information
  * ----------------
  */
 typedef struct ModifyTableState
 {
-	PlanState	ps;				/* its first field is NodeTag */
-	CmdType		operation;		/* INSERT, UPDATE, or DELETE */
-	bool		canSetTag;		/* do we set the command tag/es_processed? */
-	bool		mt_done;		/* are we done? */
-	bool		fireBSTriggers; /* do we need to fire stmt triggers? */
-	PlanState **mt_plans;		/* subplans (one per target rel) */
-	int			mt_nplans;		/* number of plans in the array */
-	int			mt_whichplan;	/* which one is being executed (0..n-1) */
+	PlanState ps;		  /* its first field is NodeTag */
+	CmdType operation;	  /* INSERT, UPDATE, or DELETE */
+	bool canSetTag;		  /* do we set the command tag/es_processed? */
+	bool mt_done;		  /* are we done? */
+	bool fireBSTriggers;  /* do we need to fire stmt triggers? */
+	PlanState **mt_plans; /* subplans (one per target rel) */
+	int mt_nplans;		  /* number of plans in the array */
+	int mt_whichplan;	  /* which one is being executed (0..n-1) */
+	bool mt_perchildplan; /* does planner construct plan for each child table */
 
-	RemoteModifyState *mt_remote_states; /* per-subplan remote modify state */
-	/*   
-	 * Attr Nums in this set is a 'long expression', i.e. longer than NAMEDATALEN.
-	 * Suppose the i'th 1 bit in long_exprs_bmp denotes number x, then the
-	 * tupdesc->attrs[x].attname doesn't contail complete expr text, need to use
-	 * long_exprs[i] instead.
-	 * All mt_plan subplans share the same column names, so they should be here
-	 * instead of RemoteModifyState.
-	 * */
-	Bitmapset *long_exprs_bmp;
-	List *long_exprs;
+	StringInfoData mt_remote_action_clause; /* 'ON DUPLICATE KEY' clause added to remote sql */
+
+	ResultRelInfo *resultRelInfo;	  /* per-subplan target relations */
+	ResultRelInfo *rootResultRelInfo; /* root target relation (partitioned
+									   * table root) */
+
+	bool is_pushdown_updel;	   /* true if this query is pushdownable delete/update */
+	List *pushdown_returning;  /* the returning clause of the pushdownable delete/update */
+	struct RemoteUD *remote_updel; /* printer generating pushed delete/update*/
+	StmtSafeHandle *active_stmts;	   /* active AsyncStmtInfo */
+	int nactive_stmts;
+	int max_actieve_stmts;
 
-	ResultRelInfo *resultRelInfo;	/* per-subplan target relations */
-	ResultRelInfo *rootResultRelInfo;	/* root target relation (partitioned
-										 * table root) */
 	TupleTableSlot *remoteReturningTupleSlot;
 	TypeInputInfo *typeInputInfo;
 	int cur_returning_idx;
 
-	List	  **mt_arowmarks;	/* per-subplan ExecAuxRowMark lists */
-	EPQState	mt_epqstate;	/* for evaluating EvalPlanQual rechecks */
-	TupleTableSlot *mt_existing;	/* slot to store existing target tuple in */
-	List	   *mt_excludedtlist;	/* the excluded pseudo relation's tlist  */
-	TupleTableSlot *mt_conflproj;	/* CONFLICT ... SET ... projection target */
+	List **mt_arowmarks;		  /* per-subplan ExecAuxRowMark lists */
+	EPQState mt_epqstate;		  /* for evaluating EvalPlanQual rechecks */
+	TupleTableSlot *mt_existing;  /* slot to store existing target tuple in */
+	List *mt_excludedtlist;		  /* the excluded pseudo relation's tlist  */
+	TupleTableSlot *mt_conflproj; /* CONFLICT ... SET ... projection target */
 
 	/* Tuple-routing support info */
 	struct PartitionTupleRouting *mt_partition_tuple_routing;
@@ -1136,6 +1134,12 @@ typedef struct ModifyTableState
 
 	/* Per plan map for tuple conversion from child to root */
 	TupleConversionMap **mt_per_subplan_tupconv_maps;
+
+	/* cached tuple conversion map to accelerate tupconv_map_for_partition()*/
+	int mt_current_partidx;
+
+	/* cache unconsumed tuples when give up connection */
+	Tuplestorestate *tuplestorestate;
 } ModifyTableState;
 
 /* ----------------
@@ -1170,6 +1174,7 @@ struct AppendState
 	struct PartitionPruneState *as_prune_state;
 	Bitmapset  *as_valid_subplans;
 	bool		(*choose_next_subplan) (AppendState *);
+	bool		keep_order;
 };
 
 /* ----------------
@@ -1272,150 +1277,47 @@ typedef struct ScanState
 
 struct SortColRef;
 
-typedef struct RelColRef
-{
-	int rel_idx;
-	int attno;
-} RelColRef;
-
 /*
-  dzw: record the owner rte-id of a remote join's output columns,
-  since TupleDesc or Form_pg_attribute has no rte-id field.
-*/
-typedef struct RelColArray
+ * The table name conflict when generating remote sql
+ */
+struct RangeTblEntry;
+typedef struct TableNameConflict
 {
-	RelColRef *base;
-	int size;
-	int capacity;
-} RelColArray;
+	int relid;
+	char *name;			/* The orignal name of the conflict table */
+	char *newName;		/* The modified name of the conflict table */
+	struct RangeTblEntry *rte;
+} TableNameConflict;
 
-/*
-  dzw: Remote leaf table scan state.
-*/
-typedef struct RemoteScanState
+typedef struct RemotePlanState
 {
 	ScanState	ss;				/* its first field is NodeTag */
+	/* The target shard id*/
+	Oid shardid;
+	/* The prepared remote sql */
 	StringInfoData remote_sql;
-	AsyncStmtInfo *asi;         /* communication channel with storage node. */
+	/* The scanlist of remote sql */
+	List *scanlist;
+	 /* communication channel with storage node. */
+	struct AsyncStmtInfo *asi;
+	StmtSafeHandle handle;
 	TypeInputInfo *typeInputInfo;
-	/*
-	 * Attr Nums in this set is a 'long expression', i.e. longer than NAMEDATALEN.
-	 * Suppose the i'th 1 bit in long_exprs_bmp denotes number x, then the
-	 * tupdesc->attrs[x].attname doesn't contail complete expr text, need to use
-	 * long_exprs[i] instead.
-	 * */
-	Bitmapset *long_exprs_bmp;
-	List *long_exprs;
-	struct SortColRef *sortcols;
-	/*
-	 * The TupleDesc in ss.ps.scandesc may be allocated with more
-	 * FormData_pg_attribute slots than ss.ps.scandesc->natts, this field
-	 * stores the real capacity of ss.ps.scandesc->attrs array, in order to
-	 * store extra attrs for quals.
-	 * */
-	int scandesc_natts_cap;
-	bool fetches_remote_data;
-
-	/* when this is in a correlated subquery, do we use dependent outer param
-	values to fetch each portion of qualified rows on each rescan, or do we fetch
-	all rows that match quals containing no dependent params all at once.
-	It's generally faster and less costly to do it the 2nd way, unless there
-	are too many qualified rows.
-	*/
+	/**
+	 * when this is in a correlated subquery, do we use dependent outer param
+	 * values to fetch each portion of qualified rows on each rescan, or do we fetch
+	 * all rows that match quals containing no dependent params all at once.
+	 * It's generally faster and less costly to do it the 2nd way, unless there
+	 * are too many qualified rows.
+	 */
 	bool		param_driven;
-
-	/*
-	  results of this remote scan is used for EXISTS() checks thus only 1 row
-	  needs to be returned.
-	*/
-	bool		check_exists;
+	List 		*param;
 
 	/*
 	  need to rewind, most likely its resultset is used as inner node result
 	  of a join. If so store result rather than use result.
 	*/
 	bool will_rewind;
-
-	/*
-	 * When multiple RemoteScan compete for the same mysql connection, the tuples of
-	 * the RemoteJoin that has occupied the connection is automatically materialized
-	 * in this tuple store.
-	 */
-	Tuplestorestate *tuplestorestate;
-	bool refill_tuplestore;
-
-	/* Generated vars of scantuple, and the coresponding exprs */
-	List *scanvars;
-	List *scanexprs;
-
-	/* Origial plan->qual */
-	List *orignal_qual;
-
-	/* Quals pushdown to the storage */
-	List *quals_pushdown;
-	List *having_pushdown;
-
-	RelColArray rtdr_rca;
-} RemoteScanState;
-
-/*
-  dzw:
-  Relation tupledesc reference used by RemoteJoinState to refer to the
-  scanned remote relations.
-*/
-typedef struct RelTupDescRef
-{
-	/*
-	  Target relation identified by rte id.
-	*/
-	int rel_idx; // rte id
-	/*
-	  The tupledesc of rel_idx
-	*/
-	TupleDesc tupdesc;
-	/*
-	  The relation that must be pinned to reference tupdesc. Only relation
-	  handles temporarily opened need to be pinned like this, those
-	  opened & owned by executor nodes are closed at end of execution
-	  as expected.
-	*/
-	Relation rel;
-	struct RelTupDescRef *next;
-} RelTupDescRef;
-
-/*
- * The table name conflict when generating remote sql
- */
-typedef struct TableNameConflict
-{
-	int relid;
-	char *name;			/* The orignal name of the conflict table */
-	char *newName;		/* The modified name of the conflict table */
-	RangeTblEntry *rte;
-} TableNameConflict;
-
-/*
-  dzw: Remote pushed-down join scan state.
-*/
-typedef struct RemoteJoinState
-{
-	RemoteScanState rss;
-	RelTupDescRef *rel_tupdescs;
-
-	/* The joined tables part of the final sql. */
-	StringInfoData target_join_sql;
-
-	/* Table name conflicts when generating remote seql */
-	List *name_conflicts;
-
-	/* Serial number of generated tableless subquery */
-	int tmp_no;
-} RemoteJoinState;
-
-/*
-  dzw: Remote pushed-down agg operation scan state.
-*/
-typedef RemoteScanState RemoteSetOpState;
+} RemotePlanState;
 
 /* ----------------
  *	 SeqScanState information
@@ -2062,7 +1964,6 @@ typedef struct SharedSortInfo
 	TuplesortInstrumentation sinstrument[FLEXIBLE_ARRAY_MEMBER];
 } SharedSortInfo;
 
-struct Remote_OLD_state;
 /* ----------------
  *	 SortState information
  * ----------------
@@ -2079,7 +1980,6 @@ typedef struct SortState
 	int64		bound_Done;		/* value of bound we did the sort with */
 	void	   *tuplesortstate; /* private state of tuplesort.c */
 	SharedSortInfo *shared_info;	/* one entry per worker */
-	struct Remote_OLD_state *remote_old_state; /* dzw: remote push down info. */
 	bool		bypass;
 } SortState;
 
@@ -2249,58 +2149,6 @@ typedef struct WindowAggState
 	TupleTableSlot *temp_slot_2;
 } WindowAggState;
 
-typedef struct AggResTuple
-{
-	/*
-	  Partial agg result returned from remote_scanstates[rss_idx]
-	*/
-	TupleTableSlot *agg_restup;
-	/*
-	  The RemoteScanState node ptr within the remote_scanstates array.
-	*/
-	int rss_idx;
-} AggResTuple;
-
-/*
-  A group of agg results with same grouping fields returned from multiple RSS
-  nodes. they should be merged to produce one agg grouping result row.
-*/
-typedef struct AggGroupResTuples
-{
-	TupleTableSlot *agrt_key; // the 1st result tuple with same grouping fields.
-	int agrt_end; // 1st unused AggResTuple* slot in mras_agg_restups.
-	/* array of mras_nplans AggResTuple slots, stores all result rows with same
-	grouping fields including the key tuple. ends with NULL if not fill. */
-	AggResTuple*mras_agg_restups;
-} AggGroupResTuples;
-
-struct AggColVal;
-
-typedef struct MergeRemoteAggState
-{
-	ScanState	ss;				/* its first field is NodeTag */
-	/* array of mras_nplans RemoteScanState as my inputs */
-	RemoteScanState **remote_scanstates;
-	int			mras_nplans;
-
-	/*
-	  keep a array sorted by grouping exprs, each array slot contains another
-	  array of TupleTableSlot ptrs, i.e. such tuples have the same grouping
-	  values from multiple leaves. merge least slot of the sorted array, and
-	  keep fetching rows and fill the array until all channels are exhausted.
-	*/
-	int mras_nkeys;
-	SortSupport mras_sortkeys;	/* array of length mras_nkeys */
-
-	// array of mras_nplans slots, may(often) not fill.
-	AggGroupResTuples *mras_agg_group_restups;
-	int agrg_end; // 1st unused AggResTuple* slot in mras_agg_restups.
-
-	// array of mras_nplans slots, may(often) not fill, for agg combination.
-	// payload count is mras_agg_group_restups->agrt_end
-	struct AggColVal *agg_col_vals;
-} MergeRemoteAggState;
-
 /* ----------------
  *	 UniqueState information
  *
@@ -2316,7 +2164,6 @@ typedef struct UniqueState
 {
 	PlanState	ps;				/* its first field is NodeTag */
 	ExprState  *eqfunction;		/* tuple equality qual */
-	struct Remote_OLD_state *remote_old_state;  /* dzw: remote push down info. */
 } UniqueState;
 
 /* ----------------
@@ -2494,7 +2341,6 @@ typedef struct LimitState
 	LimitStateCond lstate;		/* state machine status, as above */
 	int64		position;		/* 1-based index of last tuple returned */
 	TupleTableSlot *subSlot;	/* tuple last obtained from subplan */
-	struct Remote_OLD_state *remote_old_state;  /* dzw: remote push down info. */
 } LimitState;
 
 #endif							/* EXECNODES_H */
