@@ -68,19 +68,17 @@ typedef enum NodeTag
 	T_WorkTableScan,
 	T_ForeignScan,
 	T_CustomScan,
-	T_RemoteScan,
+	T_RemotePath,
+	T_RemotePlan,
 	T_Join,
 	T_NestLoop,
 	T_MergeJoin,
 	T_HashJoin,
-	T_RemoteJoin,
 	T_Material,
 	T_Sort,
 	T_Group,
 	T_Agg,
-	T_MergeRemoteAgg,
 	T_WindowAgg,
-	T_RemoteSetOp,
 	T_Unique,
 	T_Gather,
 	T_GatherMerge,
@@ -128,19 +126,15 @@ typedef enum NodeTag
 	T_WorkTableScanState,
 	T_ForeignScanState,
 	T_CustomScanState,
-	T_RemoteScanState,
 	T_JoinState,
 	T_NestLoopState,
 	T_MergeJoinState,
 	T_HashJoinState,
-	T_RemoteJoinState,
 	T_MaterialState,
 	T_SortState,
 	T_GroupState,
 	T_AggState,
-	T_MergeRemoteAggState,
 	T_WindowAggState,
-	T_RemoteSetOpState,
 	T_UniqueState,
 	T_GatherState,
 	T_GatherMergeState,
@@ -148,6 +142,7 @@ typedef enum NodeTag
 	T_SetOpState,
 	T_LockRowsState,
 	T_LimitState,
+	T_RemotePlanState,
 
 	/*
 	 * TAGS FOR PRIMITIVE NODES (primnodes.h)
@@ -243,7 +238,6 @@ typedef enum NodeTag
 	T_NestPath,
 	T_MergePath,
 	T_HashPath,
-	T_RemoteJoinPath,
 	T_AppendPath,
 	T_MergeAppendPath,
 	T_ResultPath,
@@ -257,13 +251,11 @@ typedef enum NodeTag
 	T_GroupPath,
 	T_UpperUniquePath,
 	T_AggPath,
-	T_RemoteAggPath,
 	T_GroupingSetsPath,
 	T_MinMaxAggPath,
 	T_WindowAggPath,
 	T_SetOpPath,
 	T_RecursiveUnionPath,
-	T_RemoteSetOpPath,
 	T_LockRowsPath,
 	T_ModifyTablePath,
 	T_LimitPath,
@@ -430,6 +422,17 @@ typedef enum NodeTag
 	T_CreateStatsStmt,
 	T_AlterCollationStmt,
 	T_CallStmt,
+	T_UseStmt,
+	T_ShowDiagnoStmt,
+	T_KillStmt,
+	T_ShowDatabasesStmt,
+	T_ShowSchemasStmt,
+	T_ShowTablesStmt,
+	T_ShowCreateTableStmt,
+	T_ShowProcessListStmt,
+	T_SendShardStmt,
+	T_FetchMySQLVarStmt,
+	T_MySQLVarRef,
 
 	/*
 	 * TAGS FOR PARSE TREE NODES (parsenodes.h)
@@ -826,7 +829,8 @@ typedef enum OnConflictAction
 {
 	ONCONFLICT_NONE,			/* No "ON CONFLICT" clause */
 	ONCONFLICT_NOTHING,			/* ON CONFLICT ... DO NOTHING */
-	ONCONFLICT_UPDATE			/* ON CONFLICT ... DO UPDATE */
+	ONCONFLICT_UPDATE,			/* ON CONFLICT ... DO UPDATE */
+	ONCONFLICT_REPLACE			/* REPLACE INTO ... */
 } OnConflictAction;
 
 #endif							/* NODES_H */
