@@ -681,7 +681,6 @@ typedef struct SubLink
  * SubPlan.  Note that these include the cost of the subquery proper,
  * evaluation of the testexpr if any, and any hashtable management overhead.
  */
-struct Remote_OLD_state;
 typedef struct SubPlan
 {
 	Expr		xpr;
@@ -716,7 +715,6 @@ typedef struct SubPlan
 	/* Estimated execution costs: */
 	Cost		startup_cost;	/* one-time setup cost */
 	Cost		per_call_cost;	/* cost for each subplan evaluation */
-	struct Remote_OLD_state	*remote_old_state;	/* dzw: OLD state for this subplan tree. */
 } SubPlan;
 
 /*
