@@ -50,6 +50,7 @@ enum SysCacheIdentifier
 	CLUSTER_META_NODES,
 	COLLNAMEENCNSP,
 	COLLOID,
+	COMPNODES,
 	CONDEFAULT,
 	CONNAMENSP,
 	CONSTROID,
@@ -75,8 +76,13 @@ enum SysCacheIdentifier
 	OPFAMILYAMNAMENSP,
 	OPFAMILYOID,
 	PARTRELID,
+	PGMYSQLCOLLID,
+	PGMYSQLCOLLNAMEID,
+	PGMYSQLCSCOLLNAMESID,
+	PGMYSQLCSPGENCID,
 	PROCNAMEARGSNSP,
 	PROCOID,
+	PROCMAP,
 	PUBLICATIONNAME,
 	PUBLICATIONOID,
 	PUBLICATIONREL,
@@ -88,6 +94,9 @@ enum SysCacheIdentifier
 	REPLORIGNAME,
 	RULERELNAME,
 	SEQRELID,
+	SHARD,
+	SHARDNODE,
+	SHARDNODES,
 	STATEXTNAMENSP,
 	STATEXTOID,
 	STATRELATTINH,
@@ -108,6 +117,7 @@ enum SysCacheIdentifier
 	TSTEMPLATEOID,
 	TYPENAMENSP,
 	TYPEOID,
+	TYPEMAP,
 	USERMAPPINGOID,
 	USERMAPPINGUSERSERVER
 
