@@ -134,8 +134,8 @@ def add_new_shards_to_all_computing_nodes(cluster_id, meta_conn, jscfg):
                     cur.execute("insert into pg_shard (name, id, num_nodes, master_node_id, space_volumn, num_tablets, db_cluster_id, when_created) values(%s, %s, %s, %s, %s,%s,%s, now())",
                             (shardcfg['shard_name'], shardcfg['shard_id'], shardcfg['num_nodes'], shardcfg['shard_nodes'][0]['shard_node_id'], 0, 0, cluster_id))
                     for v in shardcfg['shard_nodes']:
-                        cur.execute("insert into pg_shard_node values(%s, %s, %s, %s, %s, %s, %s, %s, now())",
-                                (v['shard_node_id'], v['port'], shardcfg['shard_id'], 0, 0, v['user'], v['ip'], v['password']))
+                        cur.execute("insert into pg_shard_node values(%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, now())",
+                                (v['shard_node_id'], v['port'], shardcfg['shard_id'], 0, 0, 0, 0, v['user'], v['ip'], v['password']))
                 cur.execute("commit")
                 break
             except psycopg2.Error as pgerr:
@@ -155,6 +155,7 @@ if __name__ == '__main__':
     parser.add_argument('--cluster_name', type=str)
     parser.add_argument('--targets', type=str, help="target shards to install, specified by shard names. If none, add all shards.")
     parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
+    parser.add_argument('--meta_ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
 
     args = parser.parse_args()
     install_names = []
@@ -174,7 +175,7 @@ if __name__ == '__main__':
     meta_jscfg = json.loads(meta_jstr)
     mysql_conn_params = {}
 
-    mysql_conn_params = common.mysql_shard_check(meta_jscfg, args.ha_mode)
+    mysql_conn_params = common.mysql_shard_check(meta_jscfg, args.meta_ha_mode)
     mysql_conn_params['database'] = 'Kunlun_Metadata_DB'
     num_done = add_shards_to_cluster(mysql_conn_params, args.cluster_name, args.config, install_names, args.ha_mode)
     print "Shard nodes successfully added to cluster {} : {}".format(args.cluster_name, num_done)
