@@ -38,11 +38,15 @@ def install_pg(config_template_file, install_path, compcfg, valgrind):
         os.makedirs(datadir)
 
     portstr = str(compcfg['port'])
+    mysql_portstr = str(compcfg['mysql_port'])
     etc_path = install_path + "/etc"
     conf_list_file = etc_path+"/instances_list.txt"
     ret = os.system("grep '^" + portstr + "==>' " + conf_list_file + " >/dev/null 2>/dev/null")
     if ret == 0:
         raise Exception("Invalid port:" + portstr + ", The port is in use!")
+    ret = os.system("grep '^" + mysql_portstr + "==>' " + conf_list_file + " >/dev/null 2>/dev/null")
+    if ret == 0:
+        raise Exception("Invalid mysql port:" + mysql_portstr + ", The mysql port is in use!")
 
     # do initdb
     cmd0 = "export LD_LIBRARY_PATH=" + install_path + "/lib:$LD_LIBRARY_PATH;"
@@ -59,6 +63,7 @@ def install_pg(config_template_file, install_path, compcfg, valgrind):
     config_template = open(conf_path, 'r').read()
     replace_items = {}
     replace_items['port_placeholder'] = portstr
+    replace_items['mysql_port_placeholder'] = mysql_portstr
     replace_items['comp_node_id_placeholder'] = str(compcfg['id'])
     replace_items['unix_socket_dir_place_holder'] = datadir
 
@@ -68,6 +73,7 @@ def install_pg(config_template_file, install_path, compcfg, valgrind):
     cnf_file.close()
     os.system('echo "host all all ' + compcfg['ip'].strip() + '/32 trust" >> ' + datadir + '/pg_hba.conf')
     os.system('echo "host all all 127.0.0.1/32  trust" >> ' + datadir + '/pg_hba.conf')
+    os.system('echo "host all agent 0.0.0.0/0 reject" >> ' + datadir + '/pg_hba.conf')
     os.system('echo "host all all 0.0.0.0/0 md5" >> ' + datadir + '/pg_hba.conf')
 
     # startup postgres, put log file in datadir too
@@ -81,7 +87,7 @@ def install_pg(config_template_file, install_path, compcfg, valgrind):
 
     # add initial user for clients to use later.
     # TODO: use more restricted privs than superuser
-    sql = "set skip_tidsync = true; CREATE USER " + compcfg['user'].strip() + " PASSWORD '" + compcfg['password'] + '\' superuser;'
+    sql = "set skip_tidsync = true; CREATE USER agent PASSWORD 'agent_pwd' superuser; CREATE USER " + compcfg['user'].strip() + " PASSWORD '" + compcfg['password'] + '\' superuser;'
     psql_cmd = cmd0 + install_path + "/bin/psql -h localhost -p" + str(compcfg['port']) + " -U " + getpass.getuser() + " -d postgres -c \"" + sql + "\""
     os.system(psql_cmd)
 
