@@ -41,6 +41,7 @@ CREATE TABLE `commit_log_template_table` (
   `txn_id` bigint unsigned NOT NULL,
   `next_txn_cmd` enum('commit','abort') NOT NULL,
   `prepare_ts` timestamp(6) default current_timestamp(6),
+  `written_shards` json NOT NULL,
   PRIMARY KEY (`txn_id`,`comp_node_id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8
 /*!50100 PARTITION BY LIST (`comp_node_id`)
@@ -140,6 +141,7 @@ CREATE TABLE `comp_nodes` (
   max_conns int unsigned NOT NULL DEFAULT 0,
 
   extra_props text,
+  `coldbackup_period` varchar(50) NOT NULL default '01:00:00-02:00:00',
 
   PRIMARY KEY (db_cluster_id, `id`),
   UNIQUE KEY `cluster_id_name` (db_cluster_id, `name`),
@@ -189,7 +191,15 @@ CREATE TABLE `meta_db_nodes` (
   `port` smallint unsigned NOT NULL,
   `user_name` varchar(64) NOT NULL,
   `passwd` varchar(120) NOT NULL,
-  `master_priority` smallint NOT NULL DEFAULT '1',
+  `master_priority` smallint NOT NULL DEFAULT 1,
+  `member_state` enum('source','replica') NOT NULL DEFAULT 'replica',
+  `sync_state` enum('fsync','async') NOT NULL DEFAULT 'fsync',
+  `degrade_conf_state` enum('ON','OFF') NOT NULL DEFAULT 'OFF',
+  `degrade_run_state` enum('ON','OFF') NOT NULL DEFAULT 'OFF',
+  `replica_delay` int NOT NULL default 0,
+  `degrade_conf_time` int NOT NULL default 0,
+  `sync_num` smallint unsigned NOT NULL DEFAULT 1,
+  `nodemgr_bin_path` varchar(8192) DEFAULT NULL,
   UNIQUE KEY `id` (`id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 /*!40101 SET character_set_client = @saved_cs_client */;
@@ -199,7 +209,7 @@ CREATE TABLE `meta_db_nodes` (
 --
 DROP TABLE IF EXISTS `server_nodes`;
 /*!40101 SET @saved_cs_client     = @@character_set_client */;
- SET character_set_client = utf8mb4 ;
+SET character_set_client = utf8mb4 ;
 CREATE TABLE `server_nodes` (
   `id` int unsigned NOT NULL AUTO_INCREMENT,
   `hostaddr` varchar(8192) character set latin1 NOT NULL,
@@ -221,15 +231,22 @@ CREATE TABLE `server_nodes` (
   `wal_log_dir` varchar(8192) character set latin1,
   -- there may be multiple storage devices, detailed stats in server_nodes_stats
   -- `total_storage` bigint unsigned NOT NULL, -- in MBs.
-  `total_mem` int unsigned NOT NULL, -- in MBs
-  `total_cpu_cores` int unsigned NOT NULL,
+  `total_mem` int unsigned DEFAULT 0, -- in MBs
+  `total_cpu_cores` int unsigned DEFAULT 0,
   -- `network_bandwidth` int unsigned NOT NULL, -- in MBps this is often consistent in a DC
   -- when the server started to be in use
   `svc_since` timestamp(6) NOT NULL DEFAULT CURRENT_TIMESTAMP(6),
   -- the port number the node_mgr on this server is listening on, if not using default one. NULL: using default app defined port.
-  nodemgr_port int,
-  nodemgr_tmp_data_abs_path text DEFAULT NULL,
-  extra_props text,
+  `nodemgr_port` int,
+  `nodemgr_bin_path` text,
+  `nodemgr_tmp_data_abs_path` text DEFAULT NULL,
+  `extra_props` text,
+  `node_stats` enum('running','idle','dead') DEFAULT 'running',
+  `nodemgr_tcp_port` int DEFAULT NULL,
+  `machine_type` enum('storage','computer') DEFAULT NULL,
+  `port_range` varchar(256) DEFAULT NULL,
+  `used_port` text,
+  `installing_port` text,
   PRIMARY KEY (`id`),
   UNIQUE KEY `hostaddr_dcid_uniq` (`hostaddr`(512),`dc_id`),
   FOREIGN KEY (dc_id) references data_centers(id)
@@ -282,6 +299,11 @@ CREATE TABLE `shards` (
   `sync_num` smallint unsigned NOT NULL default 1,
   -- extra properties
   extra_props text,
+  -- fields for rbr
+  `degrade_conf_state` enum('ON','OFF') DEFAULT 'OFF',
+  `degrade_run_state` enum('ON','OFF') DEFAULT 'OFF',
+  `degrade_conf_time` int NOT NULL default 0,
+  `coldbackup_period` varchar(50) NOT NULL default '01:00:00-02:00:00',
   PRIMARY KEY (`id`),
   UNIQUE KEY `name` (db_cluster_id, `name`),
   FOREIGN KEY (db_cluster_id)  references db_clusters(id)
@@ -318,6 +340,13 @@ CREATE TABLE `shard_nodes` (
 
   -- channel properties, such as channel name, etc.
   extra_props text,
+
+  -- fields for rbr, backup, etc.
+  `sync_state` enum('fsync','async') DEFAULT 'fsync',
+  `member_state` enum('source','replica') DEFAULT 'replica',
+  `replica_delay` int NOT NULL default 0,
+  `backup_node` enum ('OFF', 'ON') DEFAULT 'OFF',
+
   PRIMARY KEY (`id`),
   UNIQUE KEY `hostaddr_port_svrnodeid_uniq` (`hostaddr`(512),`port`,`svr_node_id`),
   FOREIGN KEY (db_cluster_id) references db_clusters(id),
@@ -420,26 +449,24 @@ create table backup_storage(
 ) ENGINE=InnoDB DEFAULT charset=utf8;
  
 -- available successful cluster backups, which can be used to restore clusters
--- rows in this table comes from cluster_shard_backup_restore_log when a backup succeeds.
-create table cluster_backups (
+create table cluster_coldbackups (
 	id serial primary key,
 	-- which backup media is this backup stored into ?
-	storage_id int unsigned not null,
+	storage_id int unsigned not null default 0,
 	-- which kunlun cluster is this from?
-	cluster_id int unsigned not null,
+	cluster_id int unsigned not null default 0,
+	-- which kunlun shard is this from?
+	shard_id int not null default 0,
+	-- which kunlun compute node is this from?
+	comp_id int not null default 0,
 	-- type of backup: all storage shards, only metadata shard, metadata shard and all storage shards
-	backup_type enum('storage_shards', 'meta_shard', 'meta_and_storage_shards') not null,
-	-- does the backup contain a computing node's full logical dump?
-	has_comp_node_dump bool not null,
-	-- start&end timestamps, comes from cluster_shard_backup_restore_log.
-	start_ts timestamp(6) not null,
-	end_ts timestamp(6) not null,
-	name varchar(256), -- a human readable string to identify the backup
+	backup_type enum('storage', 'compute') default NULL,
+	status enum('not_started', 'ongoing', 'done', 'failed') not null default 'not_started',
+	start_ts timestamp(6) not null default current_timestamp(6),
+	end_ts timestamp(6) not null default 0 ON UPDATE CURRENT_TIMESTAMP(6),
 	-- extra info for expanding 
 	memo text default null,
-	backup_addr varchar(1024), -- the root path and/or directory of the backup files.
-    FOREIGN KEY (storage_id) references backup_storage(id),
- 	FOREIGN KEY (cluster_id) references db_clusters(id)
+	backup_addr varchar(1024) -- the root path and/or directory of the backup files.
 ) ENGINE=InnoDB DEFAULT charset=utf8;
 
 -- if a cluster backup or restore fails half way, try to avoid repeated shard node backups/restores which have
@@ -471,34 +498,19 @@ create table cluster_shard_backup_restore_log (
 -- log them in order to recover from failures halfway.
 create table cluster_general_job_log (
 	id serial primary key,
-	job_id varchar(128) not null,
-	job_type varchar(128) not null,
+	job_id varchar(128),
+	related_id varchar(128),
+	job_type varchar(128) DEFAULT null,
 	-- an operation's status goes through the 3 phases: not_started -> ongoing -> done/failed
 	status enum ('not_started', 'ongoing', 'done', 'failed') not null default 'not_started',
 	-- extra info for expanding 
 	memo text default null,
 	when_started timestamp(6) not null default current_timestamp(6), -- when the operation was issued
 	when_ended timestamp(6), -- when the operation ended(either done or failed)
-	job_info varchar(256), -- optional
+	job_info text default null,
 	user_name varchar(128)
 ) ENGINE=InnoDB DEFAULT charset=utf8;
 
--- general jobs including the create and drop of a cluster, a computing node, a shard and a shard node.
--- log them in order to recover from failures halfway.
--- create table cluster_general_job_log (
---	id serial primary key,
---  related_id varchar(128) DEFAULT NULL,
---	job_type varchar(128) DEFAULT null,
---	-- an operation's status goes through the 3 phases: not_started -> ongoing -> done/failed
---	status enum ('not_started', 'ongoing', 'done', 'failed') not null default 'not_started',
---	-- extra info for expanding 
---	memo text default null,
---	when_started timestamp(6) not null default current_timestamp(6), -- when the operation was issued
---	when_ended timestamp(6), -- when the operation ended(either done or failed)
---	job_info text default null, -- optional
---	user_name varchar(128)
--- ) ENGINE=InnoDB DEFAULT charset=utf8;
-
 -- roll back record for install error
 create table cluster_roll_back_record (
 	id serial primary key,
@@ -537,4 +549,80 @@ create table table_move_jobs (
  	FOREIGN KEY (dest_shard_node) references shard_nodes(id)
 ) ENGINE=InnoDB DEFAULT charset=utf8;
 
+-- Rbr failover table
+DROP TABLE IF EXISTS `rbr_consfailover`;
+CREATE TABLE `rbr_consfailover` (
+	`id` int unsigned NOT NULL AUTO_INCREMENT,
+	`host` varchar(8192) NOT NULL,
+	`shard_id` int  NOT NULL,
+	`cluster_id` int  NOT NULL,
+	`taskid` varchar(255) NOT NULL,
+	`step` varchar(255) NOT NULL,
+	`new_master_host` varchar(255) DEFAULT NULL,
+	`description` varchar(255) DEFAULT NULL,
+	`consfailover_msg` text,
+	`timestamp` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
+	`err_code` int DEFAULT NULL,
+	`err_msg` varchar(255) DEFAULT NULL,
+	PRIMARY KEY (`id`)
+) ENGINE=InnoDB DEFAULT charset=utf8;
+
+-- info for mysqld errlog
+DROP TABLE IF EXISTS `node_mgr_mysqlerr`;
+CREATE TABLE `node_mgr_mysqlerr` (
+	`hostaddr` varchar(8192) character set latin1 NOT NULL,
+	`port` int unsigned NOT NULL,
+	`err_file` varchar(8192) NOT NULL,
+	`scan_timestamp` int unsigned NOT NULL,
+	`scan_filesize` int unsigned NOT NULL,
+	PRIMARY KEY (`hostaddr`(512), `port`)
+) ENGINE=InnoDB DEFAULT charset=utf8;
+
+DROP TABLE IF EXISTS `cluster_mgr_nodes`;
+CREATE TABLE `cluster_mgr_nodes` (
+	`id` int unsigned NOT NULL AUTO_INCREMENT,
+	`hostaddr` varchar(8192) character set latin1 NOT NULL,
+	`port` int unsigned DEFAULT NULL,
+	`member_state` enum('source','replica') DEFAULT 'replica',
+	PRIMARY KEY (`id`)
+) ENGINE=InnoDB DEFAULT charset=utf8;
+
+DROP TABLE IF EXISTS `node_map_master`;
+CREATE TABLE `node_map_master` (
+	`id` int unsigned NOT NULL AUTO_INCREMENT,
+	`cluster_id` int NOT NULL,
+	`node_host` varchar(255) NOT NULL,
+	`master_host` varchar(255) NOT NULL,
+	`master_uuid` varchar(1024) NOT NULL,
+	PRIMARY KEY (`id`)
+) ENGINE=InnoDB DEFAULT charset=utf8;
+
+DROP TABLE IF EXISTS `mysql_pg_install_log`;
+CREATE TABLE `mysql_pg_install_log` (
+  `id` bigint unsigned NOT NULL AUTO_INCREMENT,
+  `general_log_id` bigint unsigned DEFAULT NULL,
+  `install_type` varchar(50) DEFAULT NULL,
+  `when_started` timestamp(6) NOT NULL DEFAULT CURRENT_TIMESTAMP(6),
+  `when_ended` timestamp(6) NOT NULL DEFAULT 0 ON UPDATE CURRENT_TIMESTAMP(6),
+  `status` enum('not_started','ongoing','done','failed') NOT NULL DEFAULT 'not_started',
+  `job_info` text default NULL,
+  `memo` text default NULL,
+  PRIMARY KEY (`id`),
+  KEY `general_log_id` (`general_log_id`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
+
+DROP TABLE IF EXISTS `restore_log`;
+CREATE TABLE `restore_log` (
+  `id` bigint unsigned NOT NULL AUTO_INCREMENT,
+  `general_log_id` bigint unsigned DEFAULT NULL,
+  `restore_type` varchar(50) DEFAULT NULL,
+  `when_started` timestamp(6) NOT NULL DEFAULT CURRENT_TIMESTAMP(6),
+  `when_ended` timestamp(6) NOT NULL DEFAULT 0 ON UPDATE CURRENT_TIMESTAMP(6),
+  `status` enum('not_started','ongoing','done','failed') NOT NULL DEFAULT 'not_started',
+  `job_info` text default NULL,
+  `memo` text default NULL,
+  PRIMARY KEY (`id`),
+  KEY `general_log_id` (`general_log_id`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
+
 -- Dump completed on 2020-01-04 11:14:45
